pub struct StatusInterface {}Expand description
Instance of a zbus::object_server::Interface constructed using the zbus::interface macro.
Implementations
Sourceimpl StatusInterface
See crate::comm::dbus for a summary of this interface’s methods, or
crate::comm::dbus::status_interface for a summary of this interface in general.
impl StatusInterface
See crate::comm::dbus for a summary of this interface’s methods, or crate::comm::dbus::status_interface for a summary of this interface in general.
Sourcepub async fn get_overlay_status(
&self,
platform_string: &str,
overlay_handle: &str,
) -> Result<String, Error>
pub async fn get_overlay_status( &self, platform_string: &str, overlay_handle: &str, ) -> Result<String, Error>
Retrieve the status of a specific device-tree overlay.
Arguments
platform_string: Platform compatibility string.overlay_handle: The handle (name) of the device-tree overlay to query.
Returns: Result<String, fdo::Error>
Ok(String)– Status of the overlay (e.g.,"loaded","unapplied").Err(fdo::Error)If the overlay handle is empty or not found.
Examples
let status = status_interface.get_overlay_status(
"xlnx,zynqmp-pcap-fpga",
"my_overlay"
).await?;
assert_eq!(status, "applied");Trait Implementations
Sourceimpl Interface for StatusInterface
impl Interface for StatusInterface
Sourcefn name() -> InterfaceName<'static>
fn name() -> InterfaceName<'static>
Return the name of the interface. Ex: “org.foo.MyInterface”
Sourcefn spawn_tasks_for_methods(&self) -> bool
fn spawn_tasks_for_methods(&self) -> bool
Whether each method call will be handled from a different spawned task. Read more
Sourcefn get<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'life7, 'async_trait>(
&'life0 self,
__zbus__property_name: &'life1 str,
__zbus__object_server: &'life2 ObjectServer,
__zbus__connection: &'life3 Connection,
__zbus__header: Option<&'life4 Header<'life5>>,
__zbus__signal_emitter: &'life6 SignalEmitter<'life7>,
) -> Pin<Box<dyn Future<Output = Option<Result<OwnedValue>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
'life7: 'async_trait,
fn get<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'life7, 'async_trait>(
&'life0 self,
__zbus__property_name: &'life1 str,
__zbus__object_server: &'life2 ObjectServer,
__zbus__connection: &'life3 Connection,
__zbus__header: Option<&'life4 Header<'life5>>,
__zbus__signal_emitter: &'life6 SignalEmitter<'life7>,
) -> Pin<Box<dyn Future<Output = Option<Result<OwnedValue>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
'life7: 'async_trait,
Get a property value. Returns
None if the property doesn’t exist. Read moreSourcefn get_all<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'async_trait>(
&'life0 self,
__zbus__object_server: &'life1 ObjectServer,
__zbus__connection: &'life2 Connection,
__zbus__header: Option<&'life3 Header<'life4>>,
__zbus__signal_emitter: &'life5 SignalEmitter<'life6>,
) -> Pin<Box<dyn Future<Output = Result<HashMap<String, OwnedValue>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
fn get_all<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'async_trait>(
&'life0 self,
__zbus__object_server: &'life1 ObjectServer,
__zbus__connection: &'life2 Connection,
__zbus__header: Option<&'life3 Header<'life4>>,
__zbus__signal_emitter: &'life5 SignalEmitter<'life6>,
) -> Pin<Box<dyn Future<Output = Result<HashMap<String, OwnedValue>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
Return all the properties.
Sourcefn set<'call>(
&'call self,
__zbus__property_name: &'call str,
value: &'call Value<'_>,
__zbus__object_server: &'call ObjectServer,
__zbus__connection: &'call Connection,
__zbus__header: Option<&'call Header<'_>>,
__zbus__signal_emitter: &'call SignalEmitter<'_>,
) -> DispatchResult<'call>
fn set<'call>( &'call self, __zbus__property_name: &'call str, value: &'call Value<'_>, __zbus__object_server: &'call ObjectServer, __zbus__connection: &'call Connection, __zbus__header: Option<&'call Header<'_>>, __zbus__signal_emitter: &'call SignalEmitter<'_>, ) -> DispatchResult<'call>
Set a property value. Read more
Sourcefn set_mut<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'life7, 'life8, 'life9, 'async_trait>(
&'life0 mut self,
__zbus__property_name: &'life1 str,
value: &'life2 Value<'life3>,
__zbus__object_server: &'life4 ObjectServer,
__zbus__connection: &'life5 Connection,
__zbus__header: Option<&'life6 Header<'life7>>,
__zbus__signal_emitter: &'life8 SignalEmitter<'life9>,
) -> Pin<Box<dyn Future<Output = Option<Result<()>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
'life7: 'async_trait,
'life8: 'async_trait,
'life9: 'async_trait,
fn set_mut<'life0, 'life1, 'life2, 'life3, 'life4, 'life5, 'life6, 'life7, 'life8, 'life9, 'async_trait>(
&'life0 mut self,
__zbus__property_name: &'life1 str,
value: &'life2 Value<'life3>,
__zbus__object_server: &'life4 ObjectServer,
__zbus__connection: &'life5 Connection,
__zbus__header: Option<&'life6 Header<'life7>>,
__zbus__signal_emitter: &'life8 SignalEmitter<'life9>,
) -> Pin<Box<dyn Future<Output = Option<Result<()>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
'life5: 'async_trait,
'life6: 'async_trait,
'life7: 'async_trait,
'life8: 'async_trait,
'life9: 'async_trait,
Set a property value. Read more
Sourcefn call<'call>(
&'call self,
__zbus__object_server: &'call ObjectServer,
__zbus__connection: &'call Connection,
__zbus__message: &'call Message,
name: MemberName<'call>,
) -> DispatchResult<'call>
fn call<'call>( &'call self, __zbus__object_server: &'call ObjectServer, __zbus__connection: &'call Connection, __zbus__message: &'call Message, name: MemberName<'call>, ) -> DispatchResult<'call>
Call a method. Read more
Sourcefn call_mut<'call>(
&'call mut self,
__zbus__object_server: &'call ObjectServer,
__zbus__connection: &'call Connection,
__zbus__message: &'call Message,
name: MemberName<'call>,
) -> DispatchResult<'call>
fn call_mut<'call>( &'call mut self, __zbus__object_server: &'call ObjectServer, __zbus__connection: &'call Connection, __zbus__message: &'call Message, name: MemberName<'call>, ) -> DispatchResult<'call>
Call a
&mut self method. Read moreSourcefn introspect_to_writer(&self, writer: &mut dyn Write, level: usize)
fn introspect_to_writer(&self, writer: &mut dyn Write, level: usize)
Write introspection XML to the writer, with the given indentation level.